summaryrefslogtreecommitdiffstats
path: root/akregator/src/tagaction.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/tagaction.cpp')
-rw-r--r--akregator/src/tagaction.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/akregator/src/tagaction.cpp b/akregator/src/tagaction.cpp
index 20a68eb4..75ce305e 100644
--- a/akregator/src/tagaction.cpp
+++ b/akregator/src/tagaction.cpp
@@ -18,8 +18,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
//#include "menuitems.h"
@@ -44,9 +44,9 @@ class TagAction::TagActionPrivate
//TQMap<TQPopupMenu*, int> popupToId;
};
-TagAction::TagAction(const Tag& tag, const TQObject *receiver, const char *slot, TQObject *parent)
-//KAction (const TQString &text, const KShortcut &cut, const TQObject *receiver, const char *slot, TQObject *parent, const char *name=0)
- : KToggleAction(tag.name(), KShortcut(), 0, 0, parent), d(new TagActionPrivate)
+TagAction::TagAction(const Tag& tag, const TQObject *receiver, const char *slot, TQObject *tqparent)
+//KAction (const TQString &text, const KShortcut &cut, const TQObject *receiver, const char *slot, TQObject *tqparent, const char *name=0)
+ : KToggleAction(tag.name(), KShortcut(), 0, 0, tqparent), d(new TagActionPrivate)
{
d->tag = tag;
connect(this, TQT_SIGNAL(toggled(const Tag&, bool)), receiver, slot);